<?php
// $Id: main.php,v 1.1 2004/07/11 10:28:57 Farsus Exp $
// -------------------------------------------------------------------------//
//			       RUNCMS                                                   //
//                                                                          //
//	 reliable - Unique - Nocost &  Simplicity & ease off use                //
//                       < http://www.runcms.org >                          //
// -------------------------------------------------------------------------//
// Original Author: phpBB Group
// Author Website : http://www.phpbb.com
// License Type   : GPL: See /manual/LICENSES/GPL.txt
// ------------------------------------------------------------------------- //

if ( !preg_match("/admin\.php/i", _PHP_SELF) ) {
	exit();
}

include_once(XOOPS_ROOT_PATH."/modules/system/admin/userrank/userrank.php");

// ------------------------------------------------------------------------- //
$op = !empty($HTTP_POST_VARS['op']) ? $HTTP_POST_VARS['op'] : $HTTP_GET_VARS['op'];

switch($op) {
	case "RankForumAdmin":
		RankForumAdmin();
		break;

	case "RankForumEdit":
		RankForumEdit($rank_id);
		break;

	case "RankForumDel":
		RankForumDel($rank_id, $ok);
		break;

	case "RankForumAdd":
		RankForumAdd($rank_title, $rank_min, $rank_max, $rank_image, $rank_special);
		break;

	case "RankForumSave":
		RankForumSave($rank_id, $rank_title, $rank_min, $rank_max, $rank_image, $rank_special);
		break;

	default:
		RankForumAdmin();
}
?>
